@@ -6,7 +6,7 @@ acceptProject = ['arz', 'marz','rrp']
 
 
 class gerstlixAPI():
-    def __init__(self, token=None):
+    def __init__(self, token:str=None):
         self.token = token
 
     def check_work_methods(self):
@@ -149,6 +149,12 @@ class gerstlixAPI():
         else:
             return f"Проверьте serverID и fractionID на валидность"
 
+    def get_admins_list(self, server:int=None):
+        if server != None:
+            r = requests.get(f"https://api2.gerstlix.com/v1/server.getAdminsList/?token={self.token}&server={server}")
+            return r.json()
+        else:
+            return f"Введите server"
     def get_ghetto_territories(self, server:int=None):
         if server != None and server in acceptServers:
 
